#!/bin/bash

#############################################################################
# easyportal.sh v0.1.7
# by nogood (www.easy-vdr.de)
#
# kann mit folgenden Parameter aufgerufen werden:
# ---------------------------------------------------------------------------
# easyportal.sh easyinfo
#   ruft das Script easyInfo auf und gibt das Ergebnis auf StdOut aus
# ---------------------------------------------------------------------------
# easyportal.sh del /pfad/zu/datei
#   löscht die angegebene Datei und erstellst sie neu
# ---------------------------------------------------------------------------
# easyportal.sh chk pluginname
#   prüft ob ein Pluginfile existiert, gibt true oder false zurück
# ---------------------------------------------------------------------------
# easyportal.sh on pluginname
#   Aktiviert das Plugin in der vdr-setup.xml und sysconfig
# ---------------------------------------------------------------------------
# easyportal.sh off pluginname
#   Deaktiviert das Plugin in der vdr-setup.xml und sysconfig
# ---------------------------------------------------------------------------
# easyportal.sh lst
#   gibt eine Liste aller verfügbaren Plugins zurück
# ---------------------------------------------------------------------------
# easyportal.sh ver
#   gibt die Aktuell installierte easyVDR-Version zurück
# ---------------------------------------------------------------------------
# easyportal.sh startvdr
#		Startet den VDR
# ---------------------------------------------------------------------------
# easyportal.sh stopvdr
#		Stoppt den VDR
# ---------------------------------------------------------------------------
#	easyportal.sh help
#		zeigt eine kurze Beschreibung an
# ---------------------------------------------------------------------------
#	easyportal.sh hddtemp <device>
#		zeigt die Temperatur der HDD an
# ---------------------------------------------------------------------------
#	easyportal.sh hddname <device>
#		ermittelt mit hwinfo das Plattenmodell
# ---------------------------------------------------------------------------
#	easyportal.sh uptime
#		zeigt die Uptime des Systems an
# ---------------------------------------------------------------------------
#	easyportal.sh date
#		zeigt das Datum und die Systemzeit an
# ---------------------------------------------------------------------------
#	easyportal.sh timer
#		zeigt die Timer an
# ---------------------------------------------------------------------------
#	easyportal.sh vdruptime
#		uptime des VDR ermitteln
# ---------------------------------------------------------------------------
#	easyportal.sh ssh
#		startet SSHd neu
#----------------------------------------------------------------------------
#       easyportal.sh port
#               ermittelt Port von Live
#############################################################################
# Includes
#

. /usr/lib/vdr/easyvdr-config-loader
. /usr/lib/vdr/functions/easyvdr-functions-lib

# . /usr/lib/vdr/functions/easyvdr-functions-lib-var-names
# . /usr/lib/vdr/functions/easyvdr-functions-lib
. /usr/share/easyvdr/easyvdr-version

#############################################################################
# Variablen
#

# Version
EasyPortalShVersion="0.1.10"

# Pfad zu easyInfo
EasyInfoShScript="/var/www/scripts/easyinfo.sh"

# Ausgabedatei die easyInfo erstellt
EasyInfoTxtFile="/var/www/log/easyinfo.log"
EasyInfoZipFile="/var/www/log/easyinfo.log.zip"

# Temporäres Arbeitsverzeichnis
TEMPDIR="/tmp/easyvdrupdateversion"


#############################################################################
# Funktionen
#


# VDR API-Ermitteln #########################################################
function getApi {
	#API=$(/usr/vdr/vdr -V | cut -d" " -f2 | tr -d "()" | cut -d "/" -f2)	
	API=$(/usr/vdr/vdr -V  2> /dev/null | grep "The Video Disk Recorder" | cut -d" " -f2 | tr -d "()" | cut -d "/" -f2)
	if [ $?!=0 && $log=="yes" ] ; then
		logging $API
	fi
}

# Aktuell Installierte Version ermitteln ####################################
function getVersion {
	EASYVDRSUBVERS="${EASYVDRSUBVERS##*.}"
	echo $EASYVDRBASEVERS.$EASYVDRSUBVERS
}

# Plugins auflisten #########################################################
function getPlugins {
	getApi
	grep "<plugin name" $PLUGIN_CFG_DIR/setup/vdr-setup.xml | grep -v 'protected="yes"' | sort | while read a; do
		a=${a#<plugin}
		a=${a%/>}
		PL=$(echo $a | awk -F\" {'print $2'})
		if [ -f $PLUGIN_DIR"/libvdr-"$PL".so."$API ] ; then
			echo $a
		fi
	done
}

# Plugin Deaktivieren #######################################################
function PluginOff {
	/usr/bin/stopvdr >/dev/null && sleep 5
	DeactivatePlugin "$1"
	cp $CFG_DIR/sysconfig $CFG_DIR/sysconfig.$(date '+%d%m%Y%H%M')
	echo $?
	echo $(date '+%d.%m.%Y %H:%M')\;$1\;"deaktiviert" >> $2
	/usr/bin/startvdr >/dev/null && sleep 5
}

# Plugin Aktivieren #########################################################
function PluginOn() {
    /usr/bin/stopvdr >/dev/null && sleep 5
    cp $CFG_DIR/sysconfig $CFG_DIR/sysconfig.$(date '+%d%m%Y%H%M')
    ActivatePlugin "$1"
	echo $?
	echo $(date '+%d.%m.%Y %H:%M')\;$1\;"aktiviert" >> $2

	### Pluginliste in der sysconfig wieder sortieren
	#loescht in der vdr-setup.xml alle kommentare
	sed -i '{/^-/d;/^<!--/d}' $PLUGIN_CFG_DIR/setup/vdr-setup.xml
	# Aktive Plugins in der vdr-setup.xml in Liste:
	ActivatedPluginsInVDRSetupXML=$(grep -w -e "<plugin name=.*active=\"yes\"" $PLUGIN_CFG_DIR/setup/vdr-setup.xml | sed -e 's/.*<plugin name=\"//' | sed -e 's/\".*$//')
	# Liste invertieren
	for i in $ActivatedPluginsInVDRSetupXML; do
	  Plugins_to_activate=$i" "$Plugins_to_activate
	done
  	# PluginListe in der sysconfig löschen
	sed -i 's/^PLUGINLIST=.*$/PLUGINLIST=\"\"/g' $CFG_DIR/sysconfig
 	# Plugins wieder aktivieren
	ActivatePlugin $Plugins_to_activate

	/usr/bin/startvdr >/dev/null && sleep 5
}

# Prüfen ob Plugin vorhanden ist ############################################
function PluginExist() {
	getApi
	echo $PLUGIN_DIR"/libvdr-"$1".so."$API
	if [ -f $PLUGIN_DIR"/libvdr-"$1".so."$API ] ; then
		echo true
	else
		echo false
	fi
}

# Datei löschen #############################################################
function DeleteFile() {
	if [ -f "$1" ] ; then
		$(rm $1)
		$(touch $1)
	fi
}

# easyInfo ausführen ########################################################
function easyInfo {
	rm $EasyInfoZipFile
	$($EasyInfoShScript $EasyInfoTxtFile)
	zip -j $EasyInfoZipFile $EasyInfoTxtFile
	chown www-data $EasyInfoTxtFile

}

# SSH neu starten ausführen ########################################################
function ssh {
/etc/init.d/ssh restart
}

# Live-Port ermitteln ########################################
function port {
dynport=`grep PLUGINLIST $CFG_DIR/sysconfig | awk -F'-Plive' '{ print substr($2,5,4)}'`
sed -i 's/live;Live.*/live;Live;'$dynport'/' /var/www/includes/home_dienste_var.inc
}

# VDR Starten ###############################################################
function startVdr {
	/usr/bin/startvdr >/dev/null && sleep 5
}

# VDR Stoppen ###############################################################
function stopVdr {
	/usr/bin/stopvdr >/dev/null && sleep 5
}

# hddtemp ###################################################################
function HddTemp {
	hddtemp $1 -q | awk -F: {'print $3'}
}

# hddname ###################################################################
function hddname {
	hwinfo --disk --short | grep $1 | awk -F$1 {'print $2'}
}

# Uptime ####################################################################
function SysUptime {
	ruptime="$(uptime)"
 	if $(echo $ruptime | grep -E "days|day" >/dev/null); then
		TAG=$(echo $ruptime | awk '{print $3}')
		STD=$(echo $ruptime | awk '{print $5}' | awk -F: '{print $1}')
		MIN=$(echo $ruptime | awk '{print $5}' | awk -F: '{print $2}' | sed s/,//g) 
		x="$TAG,$STD,$MIN";
	else
		if $(echo $ruptime | grep -E "min" >/dev/null) ; then
			x=$(echo $ruptime | sed s/,//g | awk '{print $3}' | awk '{print "0,0,"$1}')
		else
			x=$(echo $ruptime | sed s/,//g | awk '{print $3}' | awk -F: '{print "0,"$1","$2}')
		fi		
	fi
	echo $x
}

# date ######################################################################
function eDate {
	date
}

# Timer #####################################################################
function timer {
	cat $CFG_DIR/timers.conf | awk -F: {'print $3";;"$4";;"$5";;"$8'} | sort
}

# VDR-Uptime ################################################################
function vdruptime {
	if [ -f "/var/run/easyvdr-loaded-modules" ] ; then
		stat -c%Z /var/run/easyvdr-loaded-modules
	fi
}

function vdrdate {
	date +'%Y-%m-%d %H:%M'
}

# help ######################################################################
function hilfe {
	echo ""
	echo "easyportal.sh $EasyPortalShVersion"
	echo ""
	echo "Options:"
	echo ""
	echo "    easyinfo                ruft das Script easyInfo auf und gibt das Ergebnis auf StdOut aus"
	echo "    del <datei>             löscht die angegebene Datei und erstellst sie neu"
	echo "    chk <pluginname>        prüft ob ein Pluginfile existiert, gibt true oder false zurück"
	echo "    on <pluginname>         Aktiviert das Plugin in der vdr-setup.xml und sysconfig"
	echo "    off <pluginname>        Deaktiviert das Plugin in der vdr-setup.xml und sysconfig"
	echo "    lst                     gibt eine Liste aller verfügbaren Plugins zurück"
	echo "    ver                     gibt die Aktuell installierte easyVDR-Version zurück"
	echo "    upd                     Prüft auf Updates und gibt sie aus"
	echo "    startvdr                Startet den VDR"
	echo "    stopvdr,                Stoppt den VDR"
	echo "    hddtemp <device>        Zeigt die Temperatur der angegebenen Festplatte an"
	echo "    hddname <device>        Zeigt das Festplattenmodell an"
	echo "    uptime                  Zeigt die Uptime des System an"
	echo "    vdruptime               Zeigt das Datum des VDR-Starts an"
	echo "    ssh                     Startet SSHd neu"
	echo "    help,                   zeigt diese Beschreibung an"
	echo ""
}

#############################################################################
# Sciptablauf
#

case $1 in

	easyinfo) # Aufruf von easyInfo
		easyInfo
	;;

	del) # Log Datei löschen
		DeleteFile $2
	;;

	chk) # Prüfen ob ein Plugin vorhanden ist 
		PluginExist $2
	;;

	on) # Plugin Aktivieren
		PluginOn $2 $3
	;;

	off) # Plugin Deaktivieren
		PluginOff $2 $3
	;;

	lst) # Plugins Auflisten
		getPlugins
	;;

	ver) # Installierte easyVDR-Version
		getVersion
	;;

	ssh) # Startet SSHd neu
		ssh
	;;

	port) # Liveport ermitteln
		port
	;;
	

	startvdr) # VDR Starten
		startVdr
	;;

	stopvdr) # VDR Stoppen
		stopVdr
	;;

	hddtemp) # Festplattentemp.
		HddTemp $2
	;;

	hddname) # Festplattenmodell
		hddname $2
	;;

	uptime) # Uptime
		SysUptime
	;;

	date) # Datum
		eDate
	;;

	timer) # Timer
		timer
	;;

	vdruptime)
		vdruptime
	;;

	vdrdate)
		vdrdate
	;;

	help) # Hilfe anzeigen
		hilfe
	;;

	*) # Ungültige eingabe
		hilfe
		exit 1
	;;

esac
